@@ -43,7 +43,7 @@ class SQADataSource(DataSource):
     def create(self, entity: object) -> bool:
         return self.persist(entity)
 
-    def find(self, by_type: Type, by_conditions) -> List[object]:
+    def find(self, by_type: Type, by_conditions = dict()) -> List[object]:
         query = self.session.query(by_type)
 
         for k, v in by_conditions.items():
