@@ -1,6 +1,6 @@
 from dataclasses import dataclass, field
 from enum import Enum, auto
-from typing import Tuple, Set, Union
+from typing import Tuple, Set, Union, Dict
 
 
 class Mode(Enum):
@@ -16,11 +16,11 @@ class DirtyMode(Enum):
 
 class AttributeMap:
     def __init__(
-        self,
-        from_attribute: Union[str, Tuple[str, ...]],
-        to_attribute: Union[str, Tuple[str, ...]],
-        from_attribute_type_hint: Union[str, Tuple[str, ...]] = None,
-        to_attribute_type_hint: Union[str, Tuple[str, ...]] = None,
+            self,
+            from_attribute: Union[str, Tuple[str, ...]],
+            to_attribute: Union[str, Tuple[str, ...]],
+            from_attribute_type_hint: Union[str, Tuple[str, ...]] = None,
+            to_attribute_type_hint: Union[str, Tuple[str, ...]] = None,
     ):
         self.from_attribute = from_attribute
         self.to_attribute = to_attribute
@@ -49,6 +49,8 @@ class Mapping:
     delete_orphaned_entities: bool = False
     dirty_mode: DirtyMode = field(default=DirtyMode.IGNORE)
     dirty_attribute_name: str = "pending_update"
+    left_conditions: Dict[str, type] = field(default_factory=dict)
+    right_conditions: Dict[str, type] = field(default_factory=dict)
 
     def swapped(self):
         if Mode.RIGHT_TO_LEFT not in self.modes:
@@ -63,6 +65,8 @@ class Mapping:
             self.delete_orphaned_entities,
             self.dirty_mode,
             self.dirty_attribute_name,
+            left_conditions=self.right_conditions,
+            right_conditions=self.left_conditions,
         )
 
     def from_paths(self):
