@@ -95,7 +95,7 @@ class Syncer:
         generating_classes = self._collect_linked_classes(entity_class)
         return [
             entity
-            for entity in entity_ds.all(entity_class)
+            for entity in entity_ds.find(entity_class)
             if self._is_orphaned(generating_classes, entity, entity_ds, other_ds)
         ]
 
@@ -384,7 +384,7 @@ class Syncer:
     ):
         operations = []
         from_class, to_class = mapping.entity_types
-        from_entities: List = from_ds.all(from_class)
+        from_entities: List = from_ds.find(from_class, mapping.left_conditions)
 
         for from_entity in from_entities:
             operations.extend(
